"""This is my first moduele
It's great"""

def print_lol(the_list, level):
    """this def is recursion"""
    for i in the_list:
        if isinstance(i, list):
            print_lol(i, level+1)
        else:
            for tab in range(level):
                print("\t", end="")
            print(i)
            
